/***************************************************************************
 *   Copyright (C) 2007-2013      by Gilles Maire                          *
 *   Gilles@lesjetesdelencre.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "qdictionnaire.h"
#include "configuration.h"
#include "oulipo.h"
#include "feuillestyle.h"
#include "util.h"
#include "eula.h"
#include "lanquage.h"

#include <QApplication>
#include <QtSql>
#include <QDebug>
#include <QMap>
#include <QMessageBox>
#include <QFileDialog>
#include <QTranslator>


int main(int argc, char *argv[])
{
                  QApplication app(argc, argv);
                  // on permet de ne pas appeler les settings en reprecisant le nom qdictionnaire a chaque fois
                  app.setApplicationName("qdictionnaire");
                  app.setOrganizationDomain("qdictionnaire");
                  QSettings::setDefaultFormat(QSettings::IniFormat);
                  //Ceci est necessaire pour traduire les fenetres systemes en francais.
                  //On met le fichier de traduction en ressource

                  QSettings s;
                  QTranslator translator1;
                  QTranslator translator2;

                  if (  s.value("Language").isNull() ) s.setValue("Language","fr");
                  QString codelang=s.value("Language").toString();
                  Lanquage l;
                  translator1.load(l.getApptr(codelang));
                  app.installTranslator( &translator1);
                  translator2.load(l.getSystemtr(codelang));
                  app.installTranslator(&translator2);

                  QSettings settings;

                  if ( settings.value("TaillePoliceDefaut").isNull()) settings.setValue("TaillePoliceDefaut",12);

                   if ( !settings.value("PoliceDefaut").isNull())
                  app.setFont(QFont(settings.value("PoliceDefaut").toString(),settings.value("TaillePoliceDefaut").toInt()));

                   if ( settings.value("ConditionAccepted").isNull())

                  {
                      Eula  *e = new Eula();
                      e->exec();
                  }


                bool newsettings= false;
                QString PathBase=settings.value("NomBase").toString();

                 if ( PathBase.isNull() )
{
                 newsettings=true;

#ifdef   Q_OS_MAC
                 PathBase=qApp->applicationFilePath();
                 PathBase.replace("MacOS","Resources");
                 PathBase+=".db";
#endif

#ifdef Q_OS_WIN
                 PathBase=qApp->applicationFilePath();
                 PathBase.replace(".exe",".db");
#endif

#ifdef Q_OS_LINUX
                PathBase="/usr/share/qdictionnaire/qdictionnaire.db";
#endif

}
               if (newsettings)
                      {
                       settings.setValue("RichesseRimeDefaut",2);
                       settings.setValue("Mode",1);
                       settings.setValue("AffichageDebutLigneEditeur",0);
                       settings.setValue("AfficherPrenoms",0);
                       settings.setValue("AfficherLieux",0);
                       settings.setValue("AfficherAdjectifs",1);
                       settings.setValue("AfficherNoms",1);
                       settings.setValue("AfficherVerbes",1);
                       settings.setValue("PoliceDefaut","Arial");
                       settings.setValue("NombreDerniersMotsEntres",10);
                       settings.setValue("TaillePoliceDefaut",12);
                       settings.setValue("SauvegarderAvantQuitter",1);
                       settings.setValue("Style","Normal");
                       settings.setValue("NomBase",PathBase);
                       QString dir=app.applicationDirPath();
                       settings.setValue("BinDir",dir);
                      }
                  qdictionnaire  mw;


                  if ( ! settings.value("LancerIconifie").toBool()) mw.show();
                  mw.setPathBase(PathBase);
                  mw.AppPath=app.applicationFilePath();
                  mw.m_application=&app;
                  mw.setTranslator(&translator2,&translator1);

                  // La base de données est de type SQLite
                  QSqlDatabase dicodb = QSqlDatabase::addDatabase("QSQLITE");
                  bool repeat=false;
                  do {
                  dicodb.setDatabaseName(PathBase);
                  bool baseexist=QFileInfo(PathBase).exists();
                  int basesize=QFileInfo(PathBase).size();
                  bool isfile=QFileInfo(PathBase).isFile();
                  bool opened=dicodb.open();
                  if ( ! opened || !baseexist || basesize == 0 || ! isfile )
                  {
                    QMessageBox msgBox;
                   msgBox.setText(QString("Problème ouverture de la base de données «%1»").arg(PathBase));
                   msgBox.setInformativeText("Voulez vous tenter de positionner le chemin manuellement ?");
                   msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::Close);
                   repeat=true;
                   int ret = msgBox.exec();
                   if (ret == QMessageBox::Yes)
                   {
                       PathBase=QFileDialog::getOpenFileName(0, "Ouvrir un fichier","/"," Ouvrir la base de données(* *.db)");
                       mw.setPathBase(PathBase);
                       settings.setValue("NomBase",PathBase);
                   }
                   else if (ret == QMessageBox::Close  ) repeat = false;
                  }
                  else repeat=false;
                  } while (repeat );
                  // Mise en oeuvre des feuilles de style
                  feuillestyle feuille(settings.value("Style").toString());
                   app.setStyleSheet(feuille.GetStyle());

                 qint64 pid=app.applicationPid();
                 settings.setValue("PID",pid);

          QStringList libPaths = QCoreApplication::libraryPaths();
          libPaths << QCoreApplication::applicationDirPath() + "/plugins/";
          QCoreApplication::setLibraryPaths(libPaths);


          // L'application peut s'ouvrir avec le mot cherché en argument
          if ( app.arguments().count() > 1 ) {
                  mw.setTextLineEditCherche(app.arguments().at(1));
                  mw.AfficheTabulation();
          }


          return app.exec();
}

